CodespacesPreFlightWithRepoForAuthenticatedUserParams

Struct CodespacesPreFlightWithRepoForAuthenticatedUserParams 

pub struct CodespacesPreFlightWithRepoForAuthenticatedUserParams<'req> { /* private fields */ }
Query parameters for the Get default attributes for a codespace endpoint.

Implementations

Source

impl<'req> CodespacesPreFlightWithRepoForAuthenticatedUserParams<'req>

pub fn new() -> Self

pub fn git_ref(self, git_ref: &'req str) -> Self

The branch or commit to check for a default devcontainer path. If not specified, the default branch will be checked.

pub fn client_ip(self, client_ip: &'req str) -> Self

An alternative IP for default location auto-detection, such as when proxying a request.