Method, error and parameter types for the Interactions endpoint.
Structs
Enums
- Interactions
GetRestrictions ForAuthenticated User Error - Errors for the Get interaction restrictions for your public repositories endpoint.
- Interactions
GetRestrictions ForOrg Error - Errors for the Get interaction restrictions for an organization endpoint.
- Interactions
GetRestrictions ForRepo Error - Errors for the Get interaction restrictions for a repository endpoint.
- Interactions
Remove Restrictions ForAuthenticated User Error - Errors for the Remove interaction restrictions from your public repositories endpoint.
- Interactions
Remove Restrictions ForOrg Error - Errors for the Remove interaction restrictions for an organization endpoint.
- Interactions
Remove Restrictions ForRepo Error - Errors for the Remove interaction restrictions for a repository endpoint.
- Interactions
SetRestrictions ForAuthenticated User Error - Errors for the Set interaction restrictions for your public repositories endpoint.
- Interactions
SetRestrictions ForOrg Error - Errors for the Set interaction restrictions for an organization endpoint.
- Interactions
SetRestrictions ForRepo Error - Errors for the Set interaction restrictions for a repository endpoint.