Module issues

Module issues 

Method, error and parameter types for the Issues endpoint.

Structs

Issues
IssuesListAssigneesParams
Query parameters for the List assignees endpoint.
IssuesListCommentsForRepoParams
Query parameters for the List issue comments for a repository endpoint.
IssuesListCommentsParams
Query parameters for the List issue comments endpoint.
IssuesListEventsForRepoParams
Query parameters for the List issue events for a repository endpoint.
IssuesListEventsForTimelineParams
Query parameters for the List timeline events for an issue endpoint.
IssuesListEventsParams
Query parameters for the List issue events endpoint.
IssuesListForAuthenticatedUserParams
Query parameters for the List user account issues assigned to the authenticated user endpoint.
IssuesListForOrgParams
Query parameters for the List organization issues assigned to the authenticated user endpoint.
IssuesListForRepoParams
Query parameters for the List repository issues endpoint.
IssuesListLabelsForMilestoneParams
Query parameters for the List labels for issues in a milestone endpoint.
IssuesListLabelsForRepoParams
Query parameters for the List labels for a repository endpoint.
IssuesListLabelsOnIssueParams
Query parameters for the List labels for an issue endpoint.
IssuesListMilestonesParams
Query parameters for the List milestones endpoint.
IssuesListParams
Query parameters for the List issues assigned to the authenticated user endpoint.
IssuesListSubIssuesParams
Query parameters for the List sub-issues endpoint.

Enums

IssuesAddAssigneesError
Errors for the Add assignees to an issue endpoint.
IssuesAddLabelsError
Errors for the Add labels to an issue endpoint.
IssuesAddSubIssueError
Errors for the Add sub-issue endpoint.
IssuesCheckUserCanBeAssignedError
Errors for the Check if a user can be assigned endpoint.
IssuesCheckUserCanBeAssignedToIssueError
Errors for the Check if a user can be assigned to a issue endpoint.
IssuesCreateCommentError
Errors for the Create an issue comment endpoint.
IssuesCreateError
Errors for the Create an issue endpoint.
IssuesCreateLabelError
Errors for the Create a label endpoint.
IssuesCreateMilestoneError
Errors for the Create a milestone endpoint.
IssuesDeleteCommentError
Errors for the Delete an issue comment endpoint.
IssuesDeleteLabelError
Errors for the Delete a label endpoint.
IssuesDeleteMilestoneError
Errors for the Delete a milestone endpoint.
IssuesGetCommentError
Errors for the Get an issue comment endpoint.
IssuesGetError
Errors for the Get an issue endpoint.
IssuesGetEventError
Errors for the Get an issue event endpoint.
IssuesGetLabelError
Errors for the Get a label endpoint.
IssuesGetMilestoneError
Errors for the Get a milestone endpoint.
IssuesListAssigneesError
Errors for the List assignees endpoint.
IssuesListCommentsError
Errors for the List issue comments endpoint.
IssuesListCommentsForRepoError
Errors for the List issue comments for a repository endpoint.
IssuesListError
Errors for the List issues assigned to the authenticated user endpoint.
IssuesListEventsError
Errors for the List issue events endpoint.
IssuesListEventsForRepoError
Errors for the List issue events for a repository endpoint.
IssuesListEventsForTimelineError
Errors for the List timeline events for an issue endpoint.
IssuesListForAuthenticatedUserError
Errors for the List user account issues assigned to the authenticated user endpoint.
IssuesListForOrgError
Errors for the List organization issues assigned to the authenticated user endpoint.
IssuesListForRepoError
Errors for the List repository issues endpoint.
IssuesListLabelsForMilestoneError
Errors for the List labels for issues in a milestone endpoint.
IssuesListLabelsForRepoError
Errors for the List labels for a repository endpoint.
IssuesListLabelsOnIssueError
Errors for the List labels for an issue endpoint.
IssuesListMilestonesError
Errors for the List milestones endpoint.
IssuesListSubIssuesError
Errors for the List sub-issues endpoint.
IssuesLockError
Errors for the Lock an issue endpoint.
IssuesRemoveAllLabelsError
Errors for the Remove all labels from an issue endpoint.
IssuesRemoveAssigneesError
Errors for the Remove assignees from an issue endpoint.
IssuesRemoveLabelError
Errors for the Remove a label from an issue endpoint.
IssuesRemoveSubIssueError
Errors for the Remove sub-issue endpoint.
IssuesReprioritizeSubIssueError
Errors for the Reprioritize sub-issue endpoint.
IssuesSetLabelsError
Errors for the Set labels for an issue endpoint.
IssuesUnlockError
Errors for the Unlock an issue endpoint.
IssuesUpdateCommentError
Errors for the Update an issue comment endpoint.
IssuesUpdateError
Errors for the Update an issue endpoint.
IssuesUpdateLabelError
Errors for the Update a label endpoint.
IssuesUpdateMilestoneError
Errors for the Update a milestone endpoint.

Functions

new