pub struct PatchPullsUpdate {
pub title: Option<String>,
pub body: Option<String>,
pub state: Option<String>,
pub base: Option<String>,
pub maintainer_can_modify: Option<bool>,
}Fields
title: Option<String>The title of the pull request.
body: Option<String>The contents of the pull request.
state: Option<String>State of this Pull Request. Either open or closed.
base: Option<String>The name of the branch you want your changes pulled into. This should be an existing branch on the current repository. You cannot update the base branch on a pull request to point to another repository.
maintainer_can_modify: Option<bool>Indicates whether maintainers can modify the pull request.