PersonalAccessTokenRequest

Struct PersonalAccessTokenRequest 

pub struct PersonalAccessTokenRequest {
Show 14 fields pub id: Option<i64>, pub owner: Option<SimpleUser>, pub permissions_added: Option<PersonalaccesstokenrequestPermissionsAdded>, pub permissions_upgraded: Option<PersonalaccesstokenrequestPermissionsUpgraded>, pub permissions_result: Option<PersonalaccesstokenrequestPermissionsResult>, pub repository_selection: Option<String>, pub repository_count: Option<i64>, pub repositories: Option<Vec<WebhooksRepositoriesInner>>, pub created_at: Option<String>, pub token_id: Option<i64>, pub token_name: Option<String>, pub token_expired: Option<bool>, pub token_expires_at: Option<String>, pub token_last_used_at: Option<String>,
}
Details of a Personal Access Token Request.

Fields

id: Option<i64>

Unique identifier of the request for access via fine-grained personal access token. Used as the pat_request_id parameter in the list and review API calls.

owner: Option<SimpleUser>permissions_added: Option<PersonalaccesstokenrequestPermissionsAdded>permissions_upgraded: Option<PersonalaccesstokenrequestPermissionsUpgraded>permissions_result: Option<PersonalaccesstokenrequestPermissionsResult>repository_selection: Option<String>

Type of repository selection requested.

repository_count: Option<i64>

The number of repositories the token is requesting access to. This field is only populated when repository_selection is subset.

repositories: Option<Vec<WebhooksRepositoriesInner>>

An array of repository objects the token is requesting access to. This field is only populated when repository_selection is subset.

created_at: Option<String>

Date and time when the request for access was created.

token_id: Option<i64>

Unique identifier of the user’s token. This field can also be found in audit log events and the organization’s settings for their PAT grants.

token_name: Option<String>

The name given to the user’s token. This field can also be found in an organization’s settings page for Active Tokens.

token_expired: Option<bool>

Whether the associated fine-grained personal access token has expired.

token_expires_at: Option<String>

Date and time when the associated fine-grained personal access token expires.

token_last_used_at: Option<String>

Date and time when the associated fine-grained personal access token was last used for authentication.