PostActionsCreateSelfHostedRunnerGroupForOrg

Struct PostActionsCreateSelfHostedRunnerGroupForOrg 

pub struct PostActionsCreateSelfHostedRunnerGroupForOrg {
    pub name: Option<String>,
    pub visibility: Option<String>,
    pub selected_repository_ids: Option<Vec<i32>>,
    pub runners: Option<Vec<i32>>,
    pub allows_public_repositories: Option<bool>,
    pub restricted_to_workflows: Option<bool>,
    pub selected_workflows: Option<Vec<String>>,
    pub network_configuration_id: Option<String>,
}

Fields

name: Option<String>

Name of the runner group.

visibility: Option<String>

Visibility of a runner group. You can select all repositories, select individual repositories, or limit access to private repositories.

selected_repository_ids: Option<Vec<i32>>

List of repository IDs that can access the runner group.

runners: Option<Vec<i32>>

List of runner IDs to add to the runner group.

allows_public_repositories: Option<bool>

Whether the runner group can be used by public repositories.

restricted_to_workflows: Option<bool>

If true, the runner group will be restricted to running only the workflows specified in the selected_workflows array.

selected_workflows: Option<Vec<String>>

List of workflows the runner group should be allowed to run. This setting will be ignored unless restricted_to_workflows is set to true.

network_configuration_id: Option<String>

The identifier of a hosted compute network configuration.