PostCodeSecurityCreateConfigurationForEnterprise

Struct PostCodeSecurityCreateConfigurationForEnterprise 

pub struct PostCodeSecurityCreateConfigurationForEnterprise {
Show 22 fields pub name: Option<String>, pub description: Option<String>, pub advanced_security: Option<String>, pub code_security: Option<String>, pub dependency_graph: Option<String>, pub dependency_graph_autosubmit_action: Option<String>, pub dependency_graph_autosubmit_action_options: Option<EnterprisesenterprisecodesecurityconfigurationsDependencyGraphAutosubmitActionOptions>, pub dependabot_alerts: Option<String>, pub dependabot_security_updates: Option<String>, pub code_scanning_options: Option<CodeScanningOptions>, pub code_scanning_default_setup: Option<String>, pub code_scanning_default_setup_options: Option<CodeScanningDefaultSetupOptions>, pub code_scanning_delegated_alert_dismissal: Option<String>, pub secret_protection: Option<String>, pub secret_scanning: Option<String>, pub secret_scanning_push_protection: Option<String>, pub secret_scanning_validity_checks: Option<String>, pub secret_scanning_non_provider_patterns: Option<String>, pub secret_scanning_generic_secrets: Option<String>, pub secret_scanning_delegated_alert_dismissal: Option<String>, pub private_vulnerability_reporting: Option<String>, pub enforcement: Option<String>,
}

Fields

name: Option<String>

The name of the code security configuration. Must be unique within the enterprise.

description: Option<String>

A description of the code security configuration

advanced_security: Option<String>

The enablement status of GitHub Advanced Security features. enabled will enable both Code Security and Secret Protection features. > [!WARNING] > code_security and secret_protection are deprecated values for this field. Prefer the individual code_security and secret_protection fields to set the status of these features.

code_security: Option<String>

The enablement status of GitHub Code Security features.

dependency_graph: Option<String>

The enablement status of Dependency Graph

dependency_graph_autosubmit_action: Option<String>

The enablement status of Automatic dependency submission

dependency_graph_autosubmit_action_options: Option<EnterprisesenterprisecodesecurityconfigurationsDependencyGraphAutosubmitActionOptions>dependabot_alerts: Option<String>

The enablement status of Dependabot alerts

dependabot_security_updates: Option<String>

The enablement status of Dependabot security updates

code_scanning_options: Option<CodeScanningOptions>code_scanning_default_setup: Option<String>

The enablement status of code scanning default setup

code_scanning_default_setup_options: Option<CodeScanningDefaultSetupOptions>code_scanning_delegated_alert_dismissal: Option<String>

The enablement status of code scanning delegated alert dismissal

secret_protection: Option<String>

The enablement status of GitHub Secret Protection features.

secret_scanning: Option<String>

The enablement status of secret scanning

secret_scanning_push_protection: Option<String>

The enablement status of secret scanning push protection

secret_scanning_validity_checks: Option<String>

The enablement status of secret scanning validity checks

secret_scanning_non_provider_patterns: Option<String>

The enablement status of secret scanning non provider patterns

secret_scanning_generic_secrets: Option<String>

The enablement status of Copilot secret scanning

secret_scanning_delegated_alert_dismissal: Option<String>

The enablement status of secret scanning delegated alert dismissal

private_vulnerability_reporting: Option<String>

The enablement status of private vulnerability reporting

enforcement: Option<String>

The enforcement status for a security configuration