pub struct PostCodespacesCreateWithRepoForAuthenticatedUser {
pub git_ref: Option<String>,
pub location: Option<String>,
pub geo: Option<String>,
pub client_ip: Option<String>,
pub machine: Option<String>,
pub devcontainer_path: Option<String>,
pub multi_repo_permissions_opt_out: Option<bool>,
pub working_directory: Option<String>,
pub idle_timeout_minutes: Option<i64>,
pub display_name: Option<String>,
pub retention_period_minutes: Option<i64>,
}Fields
git_ref: Option<String>Git ref (typically a branch name) for this codespace
location: Option<String>The requested location for a new codespace. Best efforts are made to respect this upon creation. Assigned by IP if not provided.
geo: Option<String>The geographic area for this codespace. If not specified, the value is assigned by IP. This property replaces location, which is closing down.
client_ip: Option<String>IP for location auto-detection when proxying a request
machine: Option<String>Machine type to use for this codespace
devcontainer_path: Option<String>Path to devcontainer.json config to use for this codespace
multi_repo_permissions_opt_out: Option<bool>Whether to authorize requested permissions from devcontainer.json
working_directory: Option<String>Working directory for this codespace
idle_timeout_minutes: Option<i64>Time in minutes before codespace stops from inactivity
display_name: Option<String>Display name for this codespace
retention_period_minutes: Option<i64>Duration in minutes after codespace has gone idle in which it will be deleted. Must be integer minutes between 0 and 43200 (30 days).