pub struct PostReposTransfer {
pub new_owner: Option<String>,
pub new_name: Option<String>,
pub team_ids: Option<Vec<i32>>,
}Fields
new_owner: Option<String>The username or organization name the repository will be transferred to.
new_name: Option<String>The new name to be given to the repository.
team_ids: Option<Vec<i32>>ID of the team or teams to add to the repository. Teams can only be added to organization-owned repositories.