pub struct PutActionsCreateOrUpdateOrgSecret {
pub encrypted_value: Option<String>,
pub key_id: Option<String>,
pub visibility: Option<String>,
pub selected_repository_ids: Option<Vec<i32>>,
}Fields
encrypted_value: Option<String>Value for your secret, encrypted with LibSodium using the public key retrieved from the Get an organization public key endpoint.
key_id: Option<String>ID of the key you used to encrypt the secret.
visibility: Option<String>Which type of organization repositories have access to the organization secret. selected means only the repositories specified by selected_repository_ids can access the secret.
selected_repository_ids: Option<Vec<i32>>An array of repository ids that can access the organization secret. You can only provide a list of repository ids when the visibility is set to selected. You can manage the list of selected repositories using the List selected repositories for an organization secret, Set selected repositories for an organization secret, and Remove selected repository from an organization secret endpoints.