pub struct RepositoryRuleParamsRequiredReviewerConfiguration {
pub file_patterns: Option<Vec<String>>,
pub minimum_approvals: Option<i64>,
pub reviewer: Option<RepositoryRuleParamsReviewer>,
}Expand description
A reviewing team, and file patterns describing which files they must approve changes to.
Fields
file_patterns: Option<Vec<String>>Array of file patterns. Pull requests which change matching files must be approved by the specified team. File patterns use the same syntax as .gitignore files.
minimum_approvals: Option<i64>Minimum number of approvals required from the specified team. If set to zero, the team will be added to the pull request but approval is optional.
reviewer: Option<RepositoryRuleParamsReviewer>Trait Implementations
Sourceimpl Clone for RepositoryRuleParamsRequiredReviewerConfiguration
impl Clone for RepositoryRuleParamsRequiredReviewerConfiguration
Sourcefn clone(&self) -> RepositoryRuleParamsRequiredReviewerConfiguration
fn clone(&self) -> RepositoryRuleParamsRequiredReviewerConfiguration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RepositoryRuleParamsRequiredReviewerConfiguration
impl Default for RepositoryRuleParamsRequiredReviewerConfiguration
Sourcefn default() -> RepositoryRuleParamsRequiredReviewerConfiguration
fn default() -> RepositoryRuleParamsRequiredReviewerConfiguration
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RepositoryRuleParamsRequiredReviewerConfiguration
impl<'de> Deserialize<'de> for RepositoryRuleParamsRequiredReviewerConfiguration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RepositoryRuleParamsRequiredReviewerConfiguration
impl PartialEq for RepositoryRuleParamsRequiredReviewerConfiguration
Sourcefn eq(&self, other: &RepositoryRuleParamsRequiredReviewerConfiguration) -> bool
fn eq(&self, other: &RepositoryRuleParamsRequiredReviewerConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RepositoryRuleParamsRequiredReviewerConfiguration