Method, error and parameter types for the Issues endpoint.
Structs
- Issues
- Issues
List Assignees Params - Query parameters for the List assignees endpoint.
- Issues
List Comments ForRepo Params - Query parameters for the List issue comments for a repository endpoint.
- Issues
List Comments Params - Query parameters for the List issue comments endpoint.
- Issues
List Events ForRepo Params - Query parameters for the List issue events for a repository endpoint.
- Issues
List Events ForTimeline Params - Query parameters for the List timeline events for an issue endpoint.
- Issues
List Events Params - Query parameters for the List issue events endpoint.
- Issues
List ForAuthenticated User Params - Query parameters for the List user account issues assigned to the authenticated user endpoint.
- Issues
List ForOrg Params - Query parameters for the List organization issues assigned to the authenticated user endpoint.
- Issues
List ForRepo Params - Query parameters for the List repository issues endpoint.
- Issues
List Labels ForMilestone Params - Query parameters for the List labels for issues in a milestone endpoint.
- Issues
List Labels ForRepo Params - Query parameters for the List labels for a repository endpoint.
- Issues
List Labels OnIssue Params - Query parameters for the List labels for an issue endpoint.
- Issues
List Milestones Params - Query parameters for the List milestones endpoint.
- Issues
List Params - Query parameters for the List issues assigned to the authenticated user endpoint.
- Issues
List SubIssues Params - Query parameters for the List sub-issues endpoint.
Enums
- Issues
AddAssignees Error - Errors for the Add assignees to an issue endpoint.
- Issues
AddLabels Error - Errors for the Add labels to an issue endpoint.
- Issues
AddSub Issue Error - Errors for the Add sub-issue endpoint.
- Issues
Check User CanBe Assigned Error - Errors for the Check if a user can be assigned endpoint.
- Issues
Check User CanBe Assigned ToIssue Error - Errors for the Check if a user can be assigned to a issue endpoint.
- Issues
Create Comment Error - Errors for the Create an issue comment endpoint.
- Issues
Create Error - Errors for the Create an issue endpoint.
- Issues
Create Label Error - Errors for the Create a label endpoint.
- Issues
Create Milestone Error - Errors for the Create a milestone endpoint.
- Issues
Delete Comment Error - Errors for the Delete an issue comment endpoint.
- Issues
Delete Label Error - Errors for the Delete a label endpoint.
- Issues
Delete Milestone Error - Errors for the Delete a milestone endpoint.
- Issues
GetComment Error - Errors for the Get an issue comment endpoint.
- Issues
GetError - Errors for the Get an issue endpoint.
- Issues
GetEvent Error - Errors for the Get an issue event endpoint.
- Issues
GetLabel Error - Errors for the Get a label endpoint.
- Issues
GetMilestone Error - Errors for the Get a milestone endpoint.
- Issues
List Assignees Error - Errors for the List assignees endpoint.
- Issues
List Comments Error - Errors for the List issue comments endpoint.
- Issues
List Comments ForRepo Error - Errors for the List issue comments for a repository endpoint.
- Issues
List Error - Errors for the List issues assigned to the authenticated user endpoint.
- Issues
List Events Error - Errors for the List issue events endpoint.
- Issues
List Events ForRepo Error - Errors for the List issue events for a repository endpoint.
- Issues
List Events ForTimeline Error - Errors for the List timeline events for an issue endpoint.
- Issues
List ForAuthenticated User Error - Errors for the List user account issues assigned to the authenticated user endpoint.
- Issues
List ForOrg Error - Errors for the List organization issues assigned to the authenticated user endpoint.
- Issues
List ForRepo Error - Errors for the List repository issues endpoint.
- Issues
List Labels ForMilestone Error - Errors for the List labels for issues in a milestone endpoint.
- Issues
List Labels ForRepo Error - Errors for the List labels for a repository endpoint.
- Issues
List Labels OnIssue Error - Errors for the List labels for an issue endpoint.
- Issues
List Milestones Error - Errors for the List milestones endpoint.
- Issues
List SubIssues Error - Errors for the List sub-issues endpoint.
- Issues
Lock Error - Errors for the Lock an issue endpoint.
- Issues
Remove AllLabels Error - Errors for the Remove all labels from an issue endpoint.
- Issues
Remove Assignees Error - Errors for the Remove assignees from an issue endpoint.
- Issues
Remove Label Error - Errors for the Remove a label from an issue endpoint.
- Issues
Remove SubIssue Error - Errors for the Remove sub-issue endpoint.
- Issues
Reprioritize SubIssue Error - Errors for the Reprioritize sub-issue endpoint.
- Issues
SetLabels Error - Errors for the Set labels for an issue endpoint.
- Issues
Unlock Error - Errors for the Unlock an issue endpoint.
- Issues
Update Comment Error - Errors for the Update an issue comment endpoint.
- Issues
Update Error - Errors for the Update an issue endpoint.
- Issues
Update Label Error - Errors for the Update a label endpoint.
- Issues
Update Milestone Error - Errors for the Update a milestone endpoint.