pub struct NullableCodespaceMachine {
pub name: Option<String>,
pub display_name: Option<String>,
pub operating_system: Option<String>,
pub storage_in_bytes: Option<i64>,
pub memory_in_bytes: Option<i64>,
pub cpus: Option<i64>,
pub prebuild_availability: Option<String>,
}Expand description
A description of the machine powering a codespace.
Fields
name: Option<String>The name of the machine.
display_name: Option<String>The display name of the machine includes cores, memory, and storage.
operating_system: Option<String>The operating system of the machine.
storage_in_bytes: Option<i64>How much storage is available to the codespace.
memory_in_bytes: Option<i64>How much memory is available to the codespace.
cpus: Option<i64>How many cores are available to the codespace.
prebuild_availability: Option<String>Whether a prebuild is currently available when creating a codespace for this machine and repository. If a branch was not specified as a ref, the default branch will be assumed. Value will be "null" if prebuilds are not supported or prebuild availability could not be determined. Value will be "none" if no prebuild is available. Latest values "ready" and "in_progress" indicate the prebuild availability status.